@@ -3,5 +3,7 @@ from .version_number import guavacado_version
 from .WebHost import WebHost
 from .WebInterface import WebInterface
 from .WebFileInterface import WebFileInterface
+from .WebSocketInterface import WebSocketInterface
+from .WebSocketMessage import WebSocketMessage
 from .BasicAuth import BasicAuth
 from .Client import Client
